function result=mygamma(z);
    T = 14;
    N = 64;
    result = 0;
    largest = 0;
    last = 0;
    for k = (0:N);
        term = (-1)^k*(T^(k+z))/(factorial(k)*(k+z));
        if (abs(term) > largest)
            largest = abs(term);
        endif;
        last = term;
        result += term;
    endfor;
    largest
    last
    Ihi = T^(z-1)*exp(-T)
    Ilo = Ihi/(1-(z-1)/T)
    I = (Ihi+Ilo)/2;
    ger = (Ihi-Ilo)/2 % gamma_error
    result += 0*I;
endfunction;

