use warnings;
use strict;
package Def;

# This file defines common parameters for some of the helper scripts.

our $out                = 'derivations';
our $full_title         = 'Derivations of Applied Mathematics';
our $author             = 'Thaddeus H. Black';
our $email              = 'thb@derivations.org';
our $email_deb          = 'thb@debian.org';
our $width              = 71;
our $basever            = '0.57';
our $main0              = 'main';
our $bib0               = 'bib';
our $dist               = 'experimental';
our $urgency            = 'none';
our $mansect            = '7';
our $name_readme        = 'README';
our $traditional_readme = 0;
our $cl_entry_dflt      = '[Add changelog entries here.]';

1;

